Package: eudysbiome
Type: Package
Title: Cartesian plot and contingency test on 16S Microbial data
Version: 1.43.0
Date: 2016-05-19
Author: Xiaoyuan Zhou, Christine Nardini
Maintainer: Xiaoyuan Zhou <zhouxiaoyuan@picb.ac.cn>
Description: eudysbiome a package that permits to annotate the differential
    genera as harmful/harmless based on their ability to contribute to host
    diseases (as indicated in literature) or unknown based on their ambiguous
    genus classification. Further, the package statistically measures the eubiotic
    (harmless genera increase or harmful genera decrease) or dysbiotic(harmless
    genera decrease or harmful genera increase) impact of a given treatment or
    environmental change on the (gut-intestinal, GI) microbiome in comparison to the
    microbiome of the reference condition.
Depends: R (>= 3.1.0)
Imports: plyr, Rsamtools, R.utils, Biostrings
License: GPL-2
LazyData: TRUE
RoxygenNote: 5.0.1
git_url: https://git.bioconductor.org/packages/eudysbiome
git_branch: devel
git_last_commit: 33f2ad5
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:34:15 UTC; biocbuild
