# Generated by roxygen2: do not edit by hand

export(Cartesian)
export(assignTax)
export(contingencyCount)
export(contingencyTest)
export(microAnnotate)
export(tableSpecies)
import(Biostrings)
import(plyr)
importFrom(R.utils,getAbsolutePath)
importFrom(R.utils,gunzip)
importFrom(Rsamtools,FaFile)
importFrom(Rsamtools,getSeq)
importFrom(Rsamtools,indexFa)
importFrom(Rsamtools,seqinfo)
