% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/eudysbiome.R
\docType{data}
\name{diffGenera}
\alias{diffGenera}
\title{Differential microbes in Genus-Species table
A data frame containing 10 differential genera and the species included, which was to be annotated as \code{"harmful"} or \code{"harmless"}.}
\format{A data frame with 26 rows and 2 columns specifying for \code{Genus} and \code{Species}.}
\usage{
data(diffGenera)
}
\description{
Differential microbes in Genus-Species table
A data frame containing 10 differential genera and the species included, which was to be annotated as \code{"harmful"} or \code{"harmless"}.
}
\keyword{datasets}

